Method: AchClient::AchWorks::CompanyInfo#initialize

Defined in:
lib/ach_client/providers/soap/ach_works/company_info.rb

#initialize(company_key:, company:, loc_i_d:, s_s_s:) ⇒ CompanyInfo

Since all these fields are generated by them, and don’t change, it really seems like they could use just one.

Parameters:

  • s_s_s (String)

    Arbitrary 3 letter code they give your company

  • loc_i_d (String)

    Another Arbitrary 4 letter code they give you…

  • company (String)

    Your user id string, used as a username

  • company_key (String)

    A key that they give you used as a password



18
19
20
21
22
23
24
25
26
27
28
# File 'lib/ach_client/providers/soap/ach_works/company_info.rb', line 18

def initialize(
  company_key:,
  company:,
  loc_i_d:,
  s_s_s:
)
  @company = company
  @company_key = company_key
  @loc_i_d = loc_i_d
  @s_s_s = s_s_s
end